@@ -7,10 +7,15 @@
 #include "HiScoreModel.h"
 #include "Helper.h"
 
+#define VER1_(x) #x
+#define VER_(x)	VER1_(x)
+#define VER VER_(MYVERSION)
+
 int main(int argc, char *argv[])
 {
     //qputenv("N900_PORTRAIT_SENSORS", "1");
 
+    qDebug() << VER;
     QApplication app(argc, argv);
 
     qmlRegisterType<Bunker>("SpaceInvaders", 1, 0, "Bunker");
