@@ -12,14 +12,14 @@ var aliens = new Array(10*5);
 
 var bombs = new Array(10); //Max of 10 bombs on screen at one time
 var score = 0;
-var dropBombChance = 2; //start chance of and alien dropping a bomb
+var dropBombChance = 100; //start chance of and alien dropping a bomb
 var alienStartSpeed = 600; //the speed the aliens move at teh start of the level
-var alienMaxSpeed = 100; //the maximum speed
-var alienSpeedRatio = 0.9 //The speed increase on the next level
+var alienMaxSpeed = 50; //the maximum speed
+var alienSpeedRatio = 0.85 //The speed increase on the next level
 
 var level = 0;
 var startlives = 3; //Edit this to cheat!
-var livesindication = new Array(startlives - 1);
+var livesindication;
 var lives;
 
 function cmdNotRunning() {
@@ -58,7 +58,7 @@ function cmdNewGame() {
     dropBombChance = 100;
 
     lives = startlives;
-    destroyLivesIndication();
+    livesindication = new Array(lives - 1);
     createLivesIndication();
 
     //Hide the logos
@@ -158,12 +158,12 @@ function cmdLevelComplete() {
         alienStartSpeed = Math.floor(alienStartSpeed * alienSpeedRatio)
     }
 
-    if (dropBombChance > 50) {
+    if (dropBombChance > 20) {
         dropBombChance -= 10; //drop more bombs!
     }
 
     //New Life every 10 levels
-    if (((level % 5) == 0) && (lives < 8) && (level != 5)) {
+    if (((level % 10) == 0) && (lives < 8)) {
         lives++;
         createLivesIndication();
         board.displayMessage("Extra Life Gained!");
@@ -236,6 +236,8 @@ function screenTap() {
 }
 
 function createLivesIndication() {
+    destroyLivesIndication();
+    livesindication = new Array(lives - 1);
     var px = 0;
     var py = 0;
 
